Exception: Flox::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Flox::Error
- Defined in:
- lib/flox.rb
Overview
The main Error class, all Exception classes inherit from this class.
The main Error class, all Exception classes inherit from this class.